==> haskell-th-lift-instances-0.1.11-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift-instances
version: 0.1.11
id: th-lift-instances-0.1.11-G3GRgWLM0QV6FREef2ZOIm
key: th-lift-instances-0.1.11-G3GRgWLM0QV6FREef2ZOIm
license: BSD-3-Clause
copyright: Copyright (C) 2013-2016 Benno Fünfstück
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
author: Benno Fünfstück
stability: experimental
homepage: http://github.com/bennofs/th-lift-instances/
synopsis: Lift instances for template-haskell for common data types.
description:
    Most data types in haskell platform do not have Lift instances. This package provides orphan instances
    for containers, text, bytestring and vector.
category: Template Haskell
abi: 7dd946a3d778de3bfefccdeba2fc0237
exposed: True
exposed-modules:
    Instances.TH.Lift
import-dirs: /usr/lib/ghc-8.4.3/site-local/th-lift-instances-0.1.11
library-dirs: /usr/lib/ghc-8.4.3/site-local/th-lift-instances-0.1.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/th-lift-instances-0.1.11
hs-libraries: HSth-lift-instances-0.1.11-G3GRgWLM0QV6FREef2ZOIm
depends:
    base-4.11.1.0 template-haskell-2.13.0.0
    th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr containers-0.5.11.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq text-1.2.3.0
    bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr=3abe31b2134622b7b297c47726ab60c8
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock
haddock-html: /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-instances-0.1.11-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift-instances
version: 0.1.11
id: th-lift-instances-0.1.11-kskbiD4rBaLror4VPYRuF
key: th-lift-instances-0.1.11-kskbiD4rBaLror4VPYRuF
license: BSD-3-Clause
copyright: Copyright (C) 2013-2016 Benno Fünfstück
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
author: Benno Fünfstück
stability: experimental
homepage: http://github.com/bennofs/th-lift-instances/
synopsis: Lift instances for template-haskell for common data types.
description:
    Most data types in haskell platform do not have Lift instances. This package provides orphan instances
    for containers, text, bytestring and vector.
category: Template Haskell
abi: 4b3baf2423a33d0a1bdd398dd6936e5f
exposed: True
exposed-modules:
    Instances.TH.Lift
import-dirs: /usr/lib/ghc-8.6.1/site-local/th-lift-instances-0.1.11
library-dirs: /usr/lib/ghc-8.6.1/site-local/th-lift-instances-0.1.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/th-lift-instances-0.1.11
hs-libraries: HSth-lift-instances-0.1.11-kskbiD4rBaLror4VPYRuF
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-JiIK3cdnl9dHd8tTTTgRnz
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock
haddock-html: /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
